# dash-google-charts

Google Charts components for Plotly Dash built on top of [react-google-charts][rgc].

**Warning**: *dash-google-charts* is still pretty experimental, the interface and
features could change, and some components may not be fully functional yet. Use
with caution.

## Getting started

Install with `pip`:

```
pip install dash-google-charts
```

Check out `examples/` for more.


[rgc]: https://react-google-charts.com/
